@@ -1,4 +1,4 @@
-// Copyright 2012 Luis Pedro Coelho <luis@luispedro.org>
+// Copyright 2012-2019 Luis Pedro Coelho <luis@luispedro.org>
 // License: MIT (see COPYING.MIT file)
 
 #ifndef LPC_TIFF_INCLUDE_GUARD_Wed_Feb__8_19_02_16_WET_2012
@@ -14,20 +14,20 @@ class TIFFFormat : public ImageFormat {
         bool can_write_multi()      const { return true; }
         bool can_write_metadata()   const { return true; }
 
-        std::auto_ptr<Image> read(byte_source* s, ImageFactory* f, const options_map& opts) {
-            std::auto_ptr<image_list> pages = this->do_read(s, f, false);
+        std::unique_ptr<Image> read(byte_source* s, ImageFactory* f, const options_map& opts) {
+            std::unique_ptr<image_list> pages = this->do_read(s, f, false);
             if (pages->size() != 1) throw ProgrammingError();
             std::vector<Image*> ims = pages->release();
-            return std::auto_ptr<Image>(ims[0]);
+            return std::unique_ptr<Image>(ims[0]);
         }
 
-        std::auto_ptr<image_list> read_multi(byte_source* s, ImageFactory* f, const options_map& opts) {
+        std::unique_ptr<image_list> read_multi(byte_source* s, ImageFactory* f, const options_map& opts) {
             return this->do_read(s, f, true);
         }
         void write(Image* input, byte_sink* output, const options_map& opts);
         void write_multi(image_list* input, byte_sink* output, const options_map& opts);
     private:
-        std::auto_ptr<image_list> do_read(byte_source* s, ImageFactory* f, bool is_multi);
+        std::unique_ptr<image_list> do_read(byte_source* s, ImageFactory* f, bool is_multi);
         void do_write(image_list* input, byte_sink* output, const options_map& opts, bool);
 };
 
@@ -38,7 +38,7 @@ class STKFormat : public ImageFormat {
         bool can_read_multi() const { return true; }
         bool can_write() const { return false; }
 
-        std::auto_ptr<image_list> read_multi(byte_source* s, ImageFactory* f);
+        std::unique_ptr<image_list> read_multi(byte_source* s, ImageFactory* f);
 };
 
 
